    Mac OS X            	   2  *G     *y                                      ATTR      *y  L  )-                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4        ,             Ejuliac-trim-base A427R7F42H !R3~v1                                        3@'\\;̗                    Hzo ضrCIqq  <?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>com.apple.security.automation.apple-events</key>
	<true/>
	<key>com.apple.security.get-task-allow</key>
	<true/>
	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
	<true/>
	<key>com.apple.security.cs.allow-jit</key>
	<true/>
	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
	<true/>
	<key>com.apple.security.cs.debugger</key>
	<true/>
	<key>com.apple.security.cs.disable-library-validation</key>
	<true/>
	<key>com.apple.security.device.audio-input</key>
	<true/>
	<key>com.apple.security.device.camera</key>
	<true/>
</dict>
</plist>
                            juliac-trim-base                  
*Hcd                   
*Hcd
                
subject.OU        
A427R7F42H               4        ,              Ejuliac-trim-base A427R7F42H ONvHl_Zt+5b4UEhY2                                                                Ƶ
:aI=mކ3 Ug]
/                                77+9n)]i'PYZ]0	*H
010
	`He 0	*H
  0>0& ?͗Iz˃Mxs]C0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
210922185510Z
310917000000Z0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0"0
	*H
  0
 ,h!TeqN
(uRDހFg) 0MLnJcLB/}%_K*To0)(4x]#*!FЉ_jq
5-'!@r7v1tpL-^Eb@7\ܥP@
#%E@g{9x43.,&%Ϊ*w_.q;Lz"Mpֆg33Z@Īs\7 00U0 0U#0+iGv	k.@GM^0D+80604+0(http://ocsp.apple.com/ocsp03-applerootca0.U'0%0#!http://crl.apple.com/root.crl0U:ivY7U0U0
*Hcd 0
	*H
  C
YCZ20V&Hc+irH[^&t#3T3"ZظKiΖ
5joΊibmJ9MעԈ3\7D7Dh
{}~̵o=zt}҈1Y`F잹@*a
pJ,Lyc%!#o[ZWEm_doD/oM=xx
V;:+eXԹ02M$9:Z\000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00!u	LrZ=0
	*H
 0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0
240912150650Z
290913150649Z010
	&,d
A427R7F42H1C0AU:Developer ID Application: Julia Computing LLC (A427R7F42H)10U
A427R7F42H10U
Julia Computing LLC10	UUS0"0
	*H
  0
 IXTVC#$
T'D`qz5c۾Lt<-ލ^R4}Gwb"BϻI٩#5=qQ_Û3(*5%b,4N	#4BMoW_ŦfL8NDJ=u"C[v8`ch%;K3ȏA'}mTl" ߲shCg]v<8i]`2Ea3/ZHLi F0B0U0 0U#0:ivY7U0r+f0d0.+0"http://certs.apple.com/devidg2.der02+0&http://ocsp.apple.com/ocsp03-devidg2010U 00
	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.07++https://www.apple.com/certificateauthority/0U%0
+0UWmDl.?^0U0
*Hcd!20140811000000Z0
*Hcd
 0
	*H
  u8V(j+FmX 0:M<Rz/<q.(ߡz=$Z-h
ׯ(ǁ4SYm$P`Δw,,ؗ'MtD!N
\F
W)ZZKxwME
Y(j9\@DztB@`V**$g߼gy;g~0Lӧ=@X#Y
ӢFZ&N1qHу!ID}ᾡ0/v|req5O+/N1Aҙ100r0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS!u	LrZ=0
	`He %0	*H
	1	*H
0	*H
	1
260106194149Z0/	*H
	1" xIO8`0*H ZGd[F0[	*Hcd	1N0+V@(~;+$ZЈ0-	`He <Zb9x8y;Zw3n0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		VkDb8ih+Av4UO4+pKySoWsnQiNk=
		</data>
		<data>
		BjxaiGI5eBH3+g/1s+I4eTv5xFo=
		</data>
	</array>
</dict>
</plist>
0
	*H
  L0I'է' 5w7jqF=0uSZn~<AU
I<6Rm+,ûKG(AWܓ<
~Jx2_{SG*q+c'oX.F;RNp٨DP@.Z_MɧӁIux%-UF%eKӋD4DCତNi\}xa<&[6H~mfĜx"-ey9GJ?0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  Vq/y챥5:_N՞`FYYz
20260106194149Z0zY4	s)
00;^0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
260105174054Z
260216174053Z0A10UTimestamp Signer MA210U

Apple Inc.10	UUS0"0
	*H
  0
 sB#EiLoP
1ɡ}l
]oUv3U^A0|
|S5qToגkH⸨
7U1w8ςr/-3Y]5&JՌRҸ^c;2)8\l@7c3"
C׊4]1ҚRjܸ?5JKz c'1UVG g(/2 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U06ގQ?L S00U0
	*H
  Y3~}uiA2#y
־9cEF֩$/lT]mkndSܛ}x*f .}FNkVHmJ$W_WiH:vuŏ袒|Vͅus;LV5yYmYyz0[uB~.f!HA$at(nEMOĽ	v5)5fbI<bC'd+H\ϋ00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS;^0	+ 0	*H
	1
*H
	0	*H
	1
260106194149Z0#	*H
	1a7]Sv~0+*H
	1000ةHYfG7 0
	*H
  1|tP$
f4̦F.4(o|Hv
[4grv*獕
OG]PfޞL=~<؁݇'vhw6hD`aRQYHXl3M@\/b
`
ۡ);s~__|
*=MߟA2Baaog9poc&EGڶ"W,ʞoxѽgbN&
Ӗ      